# unitorch.cli.models.xlm_roberta

## XLMRobertaProcessor

!!! tip
    **`core/process/xlm_roberta`** is the section for configuration of XLMRobertaProcessor.

::: unitorch.cli.models.xlm_roberta.XLMRobertaProcessor

## XLMRobertaForClassification

!!! tip
    **`core/model/classification/xlm_roberta`** is the section for configuration of XLMRobertaForClassification.

::: unitorch.cli.models.xlm_roberta.XLMRobertaForClassification

## XLMRobertaXLForClassification

!!! tip
    **`core/model/classification/xlm_roberta_xl`** is the section for configuration of XLMRobertaXLForClassification.

::: unitorch.cli.models.xlm_roberta.XLMRobertaXLForClassification

